@@ -8,17 +8,16 @@ and Auspice across computing environments such as Docker, Conda, and AWS Batch.
 
 
 import sys
-import argparse
 import traceback
-from argparse import ArgumentParser
+from argparse import ArgumentParser, Action, SUPPRESS
 from textwrap import dedent
 from types    import SimpleNamespace
 
 from .argparse    import HelpFormatter, register_commands, register_default_command
-from .command     import build, view, deploy, remote, shell, update, check_setup, login, logout, whoami, version
+from .command     import build, view, deploy, remote, shell, update, check_setup, login, logout, whoami, version, debugger
 from .errors      import NextstrainCliError
 from .util        import warn
-from .__version__ import __version__
+from .__version__ import __version__ # noqa: F401 (for re-export)
 
 
 def run(args):
@@ -36,7 +35,7 @@ def run(args):
         warn(error)
         return 1
 
-    except AssertionError as error:
+    except AssertionError:
         traceback.print_exc()
         warn("\n")
         warn(dedent("""\
@@ -73,6 +72,7 @@ def make_parser():
         logout,
         whoami,
         version,
+        debugger,
     ]
 
     register_default_command(parser)
@@ -90,7 +90,7 @@ def register_version_alias(parser):
     argument, so its useful to make that Just Work.
     """
 
-    class run_version_command(argparse.Action):
+    class run_version_command(Action):
         def __call__(self, *args, **kwargs):
             opts = SimpleNamespace(verbose = False)
             sys.exit( version.run(opts) )
@@ -98,5 +98,5 @@ def register_version_alias(parser):
     parser.add_argument(
         "--version",
         nargs  = 0,
-        help   = argparse.SUPPRESS,
+        help   = SUPPRESS,
         action = run_version_command)
